Index: /trunk/src/VBox/Frontends/VBoxManage/VBoxManageHelp.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxManage/VBoxManageHelp.cpp	(revision 75917)
+++ /trunk/src/VBox/Frontends/VBoxManage/VBoxManageHelp.cpp	(revision 75918)
@@ -1211,5 +1211,5 @@
                      "                            --upperip <upper_ip>]\n"
                      "                            [--enable | --disable]\n"
-                     "                            [--options [--vm <name> --slot <number>]\n"
+                     "                            [--options [--vm <name> --nic <1-N>]\n"
                      "                             --id <number> [--value <string> | --remove]]\n"
                      "                             (multiple options allowed after --options)\n\n"
Index: /trunk/src/VBox/Frontends/VBoxManage/VBoxManageList.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxManage/VBoxManageList.cpp	(revision 75917)
+++ /trunk/src/VBox/Frontends/VBoxManage/VBoxManageList.cpp	(revision 75918)
@@ -796,5 +796,5 @@
     CHECK_ERROR2I_RET(pSrv, GetVmSlotOptions(vmName.raw(), uSlot, ComSafeArrayAsOutParam(options)), hrcCheck);
     if (options.size())
-        RTPrintf("Options for slot #%d of '%ls':\n", uSlot, vmName.raw());
+        RTPrintf("Options for NIC %d of '%ls':\n", uSlot + 1, vmName.raw());
     for (size_t i = 0; i < options.size(); ++i)
         RTPrintf("   %ls\n", options[i]);

Index: /trunk/src/VBox/Frontends/VBoxManage/VBoxManageDHCPServer.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxManage/VBoxManageDHCPServer.cpp	(revision 75917)
+++ /trunk/src/VBox/Frontends/VBoxManage/VBoxManageDHCPServer.cpp	(revision 75918)
@@ -116,5 +116,5 @@
     { "--options",          'o', RTGETOPT_REQ_NOTHING },
     { "--vm",               'n', RTGETOPT_REQ_STRING}, /* only with -o */
-    { "--slot",             's', RTGETOPT_REQ_UINT8}, /* only with -o and -n */
+    { "--nic",              'c', RTGETOPT_REQ_UINT8}, /* only with -o and -n */
     { "--id",               'i', RTGETOPT_REQ_UINT8}, /* only with -o */
     { "--value",            'p', RTGETOPT_REQ_STRING}, /* only with -i */
@@ -240,5 +240,5 @@
                 {
         // {"--vm",                'n', RTGETOPT_REQ_STRING}, /* only with -o */
         // {"--slot",              's', RTGETOPT_REQ_UINT8}, /* only with -o and -n*/
         // {"--id",                'i', RTGETOPT_REQ_UINT8}, /* only with -o */
         // {"--value",             'p', RTGETOPT_REQ_STRING} /* only with -i */
@@ -266,5 +266,5 @@
                 break; /* end of --vm-name */
 
-            case 's': // --slot
+            case 'c': // --nic
                 {
                     if (!fVmOptionRead)
@@ -273,6 +273,11 @@
 
                     u8Slot = ValueUnion.u8;
-                }
-                break; /* end of --slot */
+
+                    if (u8Slot < 1)
+                        return errorSyntax(USAGE_DHCPSERVER,
+                                           "invalid NIC number: %u", u8Slot);
+                    --u8Slot;
+                }
+                break; /* end of --nic */
 
             case 'i': // --id
@@ -298,5 +303,5 @@
                         && u8Slot == (uint8_t)~0)
                         return errorSyntax(USAGE_DHCPSERVER,
-                                           "--slot wasn't found");
+                                           "--nic wasn't found");
 
                     DhcpOpts &opts = fVmOptionRead ? VmSlot2Options[VmNameSlotKey(pszVmName, u8Slot)]
@@ -320,5 +325,5 @@
                         && u8Slot == (uint8_t)~0)
                         return errorSyntax(USAGE_DHCPSERVER,
-                                           "--slot wasn't found");
+                                           "--nic wasn't found");
 
                     DhcpOptIds &optIds = fVmOptionRead ? VmSlot2Options2Delete[VmNameSlotKey(pszVmName, u8Slot)]
@@ -240,5 +240,5 @@
                 {
         // {"--vm",                'n', RTGETOPT_REQ_STRING}, /* only with -o */
-        // {"--slot",              's', RTGETOPT_REQ_UINT8}, /* only with -o and -n*/
+        // {"--nic",               'c', RTGETOPT_REQ_UINT8}, /* only with -o and -n*/
         // {"--id",                'i', RTGETOPT_REQ_UINT8}, /* only with -o */
         // {"--value",             'p', RTGETOPT_REQ_STRING} /* only with -i */